==> haskell-mersenne-random-pure64-0.2.2.0-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mersenne-random-pure64.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mersenne-random-pure64
version:              0.2.2.0
visibility:           public
id:                   mersenne-random-pure64-0.2.2.0-964g9B9vt302jVyD4AxrGb
key:                  mersenne-random-pure64-0.2.2.0-964g9B9vt302jVyD4AxrGb
license:              BSD-3-Clause
copyright:            (c) 2008. Don Stewart <dons00@gmail.com>
maintainer:           Don Stewart <dons00@gmail.com>
author:               Don Stewart
homepage:             http://code.haskell.org/~dons/code/mersenne-random-pure64/
synopsis:
    Generate high quality pseudorandom numbers purely using a Mersenne Twister

description:
    The Mersenne twister is a pseudorandom number generator developed by
    Makoto Matsumoto and Takuji Nishimura that is based on a matrix linear
    recurrence over a finite binary field. It provides for fast generation
    of very high quality pseudorandom numbers. The source for the C code
    can be found here:

    <http://www.math.sci.hiroshima-u.ac.jp/~m-mat/MT/emt64.html>

    This library provides a purely functional binding to the 64 bit
    classic mersenne twister, along with instances of RandomGen, so the
    generator can be used with System.Random. The generator should
    typically be a few times faster than the default StdGen (but a tad
    slower than the impure '\''mersenne-random'\'' library based on SIMD
    instructions and destructive state updates.

category:             Math, System
abi:                  47d5ae00fa3e839e88846955f6db5a60
exposed:              True
exposed-modules:
    System.Random.Mersenne.Pure64 System.Random.Mersenne.Pure64.Base
    System.Random.Mersenne.Pure64.Internal
    System.Random.Mersenne.Pure64.MTBlock

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/mersenne-random-pure64-0.2.2.0

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/mersenne-random-pure64-0.2.2.0

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/mersenne-random-pure64-0.2.2.0

hs-libraries:         HSmersenne-random-pure64-0.2.2.0-964g9B9vt302jVyD4AxrGb
include-dirs:
    /usr/lib/ghc-9.0.2/site-local/mersenne-random-pure64-0.2.2.0/include

depends:
    base-4.15.1.0 random-1.2.1-E5Bfz23dMerGrWF0X9btYW time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-mersenne-random-pure64/html/mersenne-random-pure64.haddock

haddock-html:         /usr/share/doc/haskell-mersenne-random-pure64/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mersenne-random-pure64-0.2.2.0-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mersenne-random-pure64.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mersenne-random-pure64
version:              0.2.2.0
visibility:           public
id:                   mersenne-random-pure64-0.2.2.0-1xnqB1baICBHmtwbh0jneQ
key:                  mersenne-random-pure64-0.2.2.0-1xnqB1baICBHmtwbh0jneQ
license:              BSD-3-Clause
copyright:            (c) 2008. Don Stewart <dons00@gmail.com>
maintainer:           Don Stewart <dons00@gmail.com>
author:               Don Stewart
homepage:             http://code.haskell.org/~dons/code/mersenne-random-pure64/
synopsis:
    Generate high quality pseudorandom numbers purely using a Mersenne Twister

description:
    The Mersenne twister is a pseudorandom number generator developed by
    Makoto Matsumoto and Takuji Nishimura that is based on a matrix linear
    recurrence over a finite binary field. It provides for fast generation
    of very high quality pseudorandom numbers. The source for the C code
    can be found here:

    <http://www.math.sci.hiroshima-u.ac.jp/~m-mat/MT/emt64.html>

    This library provides a purely functional binding to the 64 bit
    classic mersenne twister, along with instances of RandomGen, so the
    generator can be used with System.Random. The generator should
    typically be a few times faster than the default StdGen (but a tad
    slower than the impure '\''mersenne-random'\'' library based on SIMD
    instructions and destructive state updates.

category:             Math, System
abi:                  4e3d72fccc87d9952d5b722c302cd379
exposed:              True
exposed-modules:
    System.Random.Mersenne.Pure64 System.Random.Mersenne.Pure64.Base
    System.Random.Mersenne.Pure64.Internal
    System.Random.Mersenne.Pure64.MTBlock

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/mersenne-random-pure64-0.2.2.0

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/mersenne-random-pure64-0.2.2.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mersenne-random-pure64
hs-libraries:         HSmersenne-random-pure64-0.2.2.0-1xnqB1baICBHmtwbh0jneQ
include-dirs:
    /usr/lib/ghc-9.0.2/site-local/mersenne-random-pure64-0.2.2.0/include

depends:
    base-4.15.1.0 random-1.2.1-5J0ZhMIxycI8iOnaSxybOH time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-mersenne-random-pure64/html/mersenne-random-pure64.haddock

haddock-html:         /usr/share/doc/haskell-mersenne-random-pure64/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
